@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import copy
-import json
 
 import networkx as nx
 import numpy as np
+import orjson
 import pytest
 from numpy.testing import assert_allclose
 
@@ -20,12 +20,12 @@ from pymatgen.analysis.chemenv.coordination_environments.structure_environments
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 __author__ = "waroquiers"
 
 
-class TestConnectedComponent(PymatgenTest):
+class TestConnectedComponent(MatSciTest):
     def test_init(self):
         # Generic connected component not using EnvironmentNodes
         # (as_dict won't work on such a ConnectedComponent instance)
@@ -121,10 +121,10 @@ class TestConnectedComponent(PymatgenTest):
         assert sorted_edges == ref_sorted_edges
 
         cc_from_dict = ConnectedComponent.from_dict(cc.as_dict())
-        cc_from_json = ConnectedComponent.from_dict(json.loads(json.dumps(cc.as_dict())))
+        cc_from_json = ConnectedComponent.from_dict(orjson.loads(orjson.dumps(cc.as_dict()).decode()))
         loaded_cc_list = [cc_from_dict, cc_from_json]
         json_str = self.assert_msonable(cc)
-        cc_from_json = ConnectedComponent.from_dict(json.loads(json_str))
+        cc_from_json = ConnectedComponent.from_dict(orjson.loads(json_str))
         loaded_cc_list.append(cc_from_json)
         for loaded_cc in loaded_cc_list:
             assert loaded_cc.graph.number_of_nodes() == 3
@@ -838,8 +838,8 @@ Node #3 Li (O:6), connected to :
 
     def test_coordination_sequences(self):
         BaTiO3_se_fpath = f"{TEST_FILES_DIR}/analysis/chemenv/structure_environments/se_mp-5020.json"
-        with open(BaTiO3_se_fpath) as file:
-            dct = json.load(file)
+        with open(BaTiO3_se_fpath, "rb") as file:
+            dct = orjson.loads(file.read())
         struct_envs = StructureEnvironments.from_dict(dct)
         lse = LightStructureEnvironments.from_structure_environments(
             strategy=SimplestChemenvStrategy(), structure_environments=struct_envs
