@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-import json
-
+import orjson
 from numpy.testing import assert_allclose
 from pytest import approx
 
@@ -22,7 +21,7 @@ from pymatgen.analysis.chemenv.coordination_environments.structure_environments
 )
 from pymatgen.analysis.chemenv.coordination_environments.voronoi import DetailedVoronoiContainer
 from pymatgen.core.structure import Structure
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 __author__ = "waroquiers"
 
@@ -30,15 +29,15 @@ json_dir = f"{TEST_FILES_DIR}/analysis/chemenv/json"
 struct_env_dir = f"{TEST_FILES_DIR}/analysis/chemenv/structure_environments"
 
 
-class TestReadWriteChemenv(PymatgenTest):
+class TestReadWriteChemenv(MatSciTest):
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.lgf = LocalGeometryFinder()
         cls.lgf.setup_parameters(centering_type="standard")
 
     def test_read_write_structure_environments(self):
-        with open(f"{json_dir}/test_T--4_FePO4_icsd_4266.json", encoding="utf-8") as file:
-            dd = json.load(file)
+        with open(f"{json_dir}/test_T--4_FePO4_icsd_4266.json", "rb") as file:
+            dd = orjson.loads(file.read())
 
         atom_indices = dd["atom_indices"]
 
@@ -48,11 +47,11 @@ class TestReadWriteChemenv(PymatgenTest):
             only_indices=atom_indices, maximum_distance_factor=2.25, get_from_hints=True
         )
 
-        with open(f"{self.tmp_path}/se.json", mode="w", encoding="utf-8") as file:
-            json.dump(se.as_dict(), file)
+        with open(f"{self.tmp_path}/se.json", "wb") as file:
+            file.write(orjson.dumps(se.as_dict(), option=orjson.OPT_SERIALIZE_NUMPY))
 
-        with open(f"{self.tmp_path}/se.json", encoding="utf-8") as file:
-            dd = json.load(file)
+        with open(f"{self.tmp_path}/se.json", "rb") as file:
+            dd = orjson.loads(file.read())
 
         se2 = StructureEnvironments.from_dict(dd)
 
@@ -63,21 +62,21 @@ class TestReadWriteChemenv(PymatgenTest):
             structure_environments=se, strategy=strategy, valences="undefined"
         )
 
-        with open(f"{self.tmp_path}/lse.json", mode="w", encoding="utf-8") as file:
-            json.dump(
-                lse.as_dict(),
-                file,
-                default=lambda obj: getattr(obj, "tolist", lambda: obj)(),
-            )
+        with open(f"{self.tmp_path}/lse.json", "wb") as file:
 
-        with open(f"{self.tmp_path}/lse.json", encoding="utf-8") as file:
-            LightStructureEnvironments.from_dict(json.load(file))
+            def default(obj):
+                return getattr(obj, "tolist", lambda: obj)()
+
+            file.write(orjson.dumps(lse.as_dict(), default=default))
+
+        with open(f"{self.tmp_path}/lse.json", "rb") as file:
+            LightStructureEnvironments.from_dict(orjson.loads(file.read()))
 
         # assert lse == lse2
 
     def test_structure_environments_neighbors_sets(self):
-        with open(f"{struct_env_dir}/se_mp-7000.json", encoding="utf-8") as file:
-            dct = json.load(file)
+        with open(f"{struct_env_dir}/se_mp-7000.json", "rb") as file:
+            dct = orjson.loads(file.read())
 
         struct_envs = StructureEnvironments.from_dict(dct)
 
@@ -131,7 +130,7 @@ class TestReadWriteChemenv(PymatgenTest):
             str(nb_set) == "Neighbors Set for site #6 :\n - Coordination number : 4\n - Voronoi indices : 1, 4, 5, 6\n"
         )
 
-        assert nb_set == nb_set
+        assert nb_set == nb_set  # noqa: PLR0124
 
         assert hash(nb_set) == 4
 
@@ -221,8 +220,8 @@ class TestReadWriteChemenv(PymatgenTest):
         assert multi_weights_strategy_2 != multi_weights_strategy_3
 
     def test_read_write_voronoi(self):
-        with open(f"{json_dir}/test_T--4_FePO4_icsd_4266.json", encoding="utf-8") as file:
-            dd = json.load(file)
+        with open(f"{json_dir}/test_T--4_FePO4_icsd_4266.json", "rb") as file:
+            dd = orjson.loads(file.read())
 
         struct = Structure.from_dict(dd["structure"])
 
@@ -230,11 +229,11 @@ class TestReadWriteChemenv(PymatgenTest):
 
         detailed_voronoi_container = DetailedVoronoiContainer(structure=struct, valences=valences)
 
-        with open(f"{self.tmp_path}/se.json", mode="w", encoding="utf-8") as file:
-            json.dump(detailed_voronoi_container.as_dict(), file)
+        with open(f"{self.tmp_path}/se.json", "wb") as file:
+            file.write(orjson.dumps(detailed_voronoi_container.as_dict(), option=orjson.OPT_SERIALIZE_NUMPY))
 
-        with open(f"{self.tmp_path}/se.json", encoding="utf-8") as file:
-            dd = json.load(file)
+        with open(f"{self.tmp_path}/se.json", "rb") as file:
+            dd = orjson.loads(file.read())
 
         detailed_voronoi_container2 = DetailedVoronoiContainer.from_dict(dd)
 
