@@ -1,20 +1,18 @@
 from __future__ import annotations
 
-import random
-
 import numpy as np
 
 from pymatgen.analysis.chemenv.coordination_environments.voronoi import DetailedVoronoiContainer
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 __author__ = "waroquiers"
 
 img_files_dir = f"{TEST_FILES_DIR}/analysis/chemenv/images"
 
 
-class TestVoronoiContainer(PymatgenTest):
+class TestVoronoiContainer(MatSciTest):
     def test_voronoi(self):
         # Define a cubic lattice and a list of species (to be used for the fake structures)
         cubic_lattice = Lattice.cubic(10)
@@ -31,7 +29,8 @@ class TestVoronoiContainer(PymatgenTest):
             (5, [5, 5, 3.96]),
             (6, [5, 5, 6.05]),
         ]
-        random.shuffle(order_and_coords)
+        rng = np.random.default_rng()
+        rng.shuffle(order_and_coords)
         arr_sorted = np.argsort([oc[0] for oc in order_and_coords]) + 1
         coords.extend([oc[1] for oc in order_and_coords])
         fake_structure = Structure(cubic_lattice, species, coords, coords_are_cartesian=True)
@@ -89,7 +88,7 @@ class TestVoronoiContainer(PymatgenTest):
             (5, [5, 5, 3.92]),
             (6, [5, 5, 6.09]),
         ]
-        random.shuffle(order_and_coords)
+        rng.shuffle(order_and_coords)
         arr_sorted = np.argsort([oc[0] for oc in order_and_coords]) + 1
         coords2.extend([oc[1] for oc in order_and_coords])
         fake_structure2 = Structure(cubic_lattice, species, coords2, coords_are_cartesian=True)
