@@ -7,13 +7,13 @@ from numpy.testing import assert_allclose
 from pytest import approx
 
 from pymatgen.analysis.chemenv.utils.coordination_geometry_utils import Plane
-from pymatgen.util.testing import PymatgenTest
+from pymatgen.util.testing import MatSciTest
 
 __author__ = "David Waroquiers"
 
 
-class TestPlanesUtils(PymatgenTest):
-    def setUp(self):
+class TestPlanesUtils(MatSciTest):
+    def setup_method(self):
         # Test of plane 4x + 2y - 4z + 3 = 0 (used in most test cases)
         self.expected_coefficients = np.array([4, 2, -4, 3], float)
         self.p1 = np.array([0, 0, 0.75])
