@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from unittest import TestCase
-
 import numpy as np
 from pytest import approx
 
@@ -10,8 +8,8 @@ from pymatgen.core import Structure
 from pymatgen.util.testing import TEST_FILES_DIR
 
 
-class TestJahnTeller(TestCase):
-    def setUp(self):
+class TestJahnTeller:
+    def setup_method(self):
         self.jt = JahnTellerAnalyzer()
 
     def test_jahn_teller_species_analysis(self):
