@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from unittest import TestCase
-
 import numpy as np
 import pytest
 from matplotlib.figure import Figure as MplFigure
@@ -17,8 +15,8 @@ from pymatgen.core.composition import Composition, Element
 from pymatgen.entries.computed_entries import ComputedEntry
 
 
-class TestInterfaceReaction(TestCase):
-    def setUp(self):
+class TestInterfaceReaction:
+    def setup_method(self):
         self.entries = [
             ComputedEntry(Composition("Li"), 0),
             ComputedEntry(Composition("Mn"), 0),
@@ -179,13 +177,14 @@ class TestInterfaceReaction(TestCase):
 
     def test_get_entry_energy(self):
         comp = Composition("MnO3")
-        with pytest.warns(UserWarning) as warns:
+        with pytest.warns(
+            UserWarning,
+            match=(
+                "The reactant MnO3 has no matching entry with negative formation energy, instead "
+                "convex hull energy for this composition will be used for reaction energy calculation."
+            ),
+        ):
             energy = InterfacialReactivity._get_entry_energy(self.pd, comp)
-        assert len(warns) == 1
-        assert str(warns[0].message) == (
-            "The reactant MnO3 has no matching entry with negative formation energy, instead "
-            "convex hull energy for this composition will be used for reaction energy calculation."
-        )
 
         test1 = np.isclose(energy, -30, atol=1e-3)
         assert test1, f"_get_entry_energy: energy for {comp.reduced_formula} is wrong!"
@@ -226,12 +225,14 @@ class TestInterfaceReaction(TestCase):
         assert test4, "_get_energy: gets error. "
 
     def test_get_reaction(self):
-        assert str(self.irs[0]._get_reaction(0.5)) == "0.5 Mn + 0.5 O2 -> 0.5 MnO2", (
-            "_get_reaction: reaction not involving chempots species gets error!"
-        )
-        assert str(self.irs[3]._get_reaction(0.666666)) == "0.5 Li2O + 0.5 Mn -> Li + 0.25 MnO2 + 0.25 Mn", (
-            "_get_reaction: reaction involving chempots species gets error!"
-        )
+        rxnstr = str(self.irs[0]._get_reaction(0.5))
+        assert "0.5 Mn" in rxnstr
+        assert "0.5 O2" in rxnstr
+        assert "0.5 MnO2" in rxnstr
+        rxnstr = str(self.irs[3]._get_reaction(0.666666))
+        assert "0.5 Li2O" in rxnstr
+        assert "0.5 Mn" in rxnstr
+        assert "0.25 MnO2" in rxnstr
 
     def test_get_get_elmt_amt_in_rxt(self):
         rxt1 = Reaction(
@@ -365,7 +366,7 @@ class TestInterfaceReaction(TestCase):
                 relative_vectors_1 = [(x - x_kink[0], e - energy_kink[0]) for x, e in points]
                 relative_vectors_2 = [(x - x_kink[-1], e - energy_kink[-1]) for x, e in points]
                 relative_vectors = zip(relative_vectors_1, relative_vectors_2, strict=True)
-                positions = [np.cross(v1, v2) for v1, v2 in relative_vectors]
+                positions = [v1[0] * v2[1] - v1[1] * v2[0] for v1, v2 in relative_vectors]
                 assert np.all(np.array(positions) <= 0)
 
                 hull = ConvexHull(points)
