@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-import os
-import unittest
+import platform
 
 import numpy as np
 import pytest
@@ -26,14 +25,14 @@ try:
 except (ImportError, RuntimeError):
     openbabel = None
 
-TEST_DIR = f"{TEST_FILES_DIR}/molecules/molecule_matcher"
+TEST_DIR = f"{TEST_FILES_DIR}/analysis/molecule_matcher"
 
 
 ob_align_missing = openbabel is None or "OBAlign" not in dir(openbabel)
 
 
 def rotate(mol, seed):
-    """Performs a random rotation of the sites in a structure.
+    """Perform a random rotation of the sites in a structure.
 
     Args:
         mol (Molecule): The Molecule object which will be transformed.
@@ -47,7 +46,7 @@ def rotate(mol, seed):
 
 
 def perturb(mol, scale, seed):
-    """Performs a random perturbation of the sites in a structure.
+    """Perform a random perturbation of the sites in a structure.
 
     Args:
         scale (float): Distance in angstroms by which to perturb each site.
@@ -56,12 +55,12 @@ def perturb(mol, scale, seed):
     rng = np.random.default_rng(seed=seed)
 
     dV = rng.normal(scale=scale, size=(len(mol), 3))
-    for site, dv in zip(mol, dV):
+    for site, dv in zip(mol, dV, strict=True):
         site.coords += dv
 
 
 def permute(mol, seed):
-    """Performs a random permutation of the sites in a structure.
+    """Perform a random permutation of the sites in a structure.
 
     Args:
         seed (int): The seed value for the random generator.
@@ -147,39 +146,42 @@ def generate_Si2O_cluster():
     XYZ(mol2).write_file(f"{TEST_DIR}/Si2O_cluster_2.xyz")
 
 
-@unittest.skipIf(ob_align_missing, "OBAlign is missing, Skipping")
-class TestMoleculeMatcher(unittest.TestCase):
+@pytest.mark.skipif(ob_align_missing, reason="OBAlign is missing, Skipping")
+class TestMoleculeMatcher:
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_fit(self):
         self.fit_with_mapper(IsomorphismMolAtomMapper())
         self.fit_with_mapper(InchiMolAtomMapper())
 
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_get_rmsd(self):
         mol_matcher = MoleculeMatcher()
         mol1 = Molecule.from_file(f"{TEST_DIR}/t3.xyz")
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
         assert f"{mol_matcher.get_rmsd(mol1, mol2):7.3}" == "0.00488"
 
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_group_molecules(self):
         mol_matcher = MoleculeMatcher(tolerance=0.001)
-        with open(f"{TEST_DIR}/mol_list.txt") as file:
-            filename_list = [line.strip() for line in file.readlines()]
-        mol_list = [Molecule.from_file(os.path.join(TEST_DIR, f)) for f in filename_list]
+        with open(f"{TEST_DIR}/mol_list.txt", encoding="utf-8") as file:
+            filename_list = [line.strip() for line in file]
+        mol_list = [Molecule.from_file(f"{TEST_DIR}/{file}") for file in filename_list]
         mol_groups = mol_matcher.group_molecules(mol_list)
         filename_groups = [[filename_list[mol_list.index(m)] for m in g] for g in mol_groups]
-        with open(f"{TEST_DIR}/grouped_mol_list.txt") as file:
+        with open(f"{TEST_DIR}/grouped_mol_list.txt", encoding="utf-8") as file:
             grouped_text = file.read().strip()
         assert str(filename_groups) == grouped_text
 
     def test_to_and_from_dict(self):
         mol_matcher = MoleculeMatcher(tolerance=0.5, mapper=InchiMolAtomMapper(angle_tolerance=50.0))
-        d = mol_matcher.as_dict()
-        mm2 = MoleculeMatcher.from_dict(d)
-        assert d == mm2.as_dict()
+        dct = mol_matcher.as_dict()
+        mm2 = MoleculeMatcher.from_dict(dct)
+        assert dct == mm2.as_dict()
 
         mol_matcher = MoleculeMatcher(tolerance=0.5, mapper=IsomorphismMolAtomMapper())
-        d = mol_matcher.as_dict()
-        mm2 = MoleculeMatcher.from_dict(d)
-        assert d == mm2.as_dict()
+        dct = mol_matcher.as_dict()
+        mm2 = MoleculeMatcher.from_dict(dct)
+        assert dct == mm2.as_dict()
 
     def fit_with_mapper(self, mapper):
         coords = [
@@ -237,24 +239,28 @@ class TestMoleculeMatcher(unittest.TestCase):
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
         assert not mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_strange_inchi(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/k1.sdf")
         mol2 = Molecule.from_file(f"{TEST_DIR}/k2.sdf")
         assert mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_thiane(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/thiane1.sdf")
         mol2 = Molecule.from_file(f"{TEST_DIR}/thiane2.sdf")
         assert not mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_thiane_ethynyl(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/thiane_ethynyl1.sdf")
         mol2 = Molecule.from_file(f"{TEST_DIR}/thiane_ethynyl2.sdf")
         assert not mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.xfail(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_cdi_23(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/cdi_23_1.xyz")
@@ -262,7 +268,7 @@ class TestMoleculeMatcher(unittest.TestCase):
         assert not mol_matcher.fit(mol1, mol2)
 
 
-class TestKabschMatcher(unittest.TestCase):
+class TestKabschMatcher:
     def test_get_rmsd(self):
         mol1 = Molecule.from_file(f"{TEST_DIR}/t3.xyz")
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
@@ -305,7 +311,10 @@ class TestKabschMatcher(unittest.TestCase):
 
         mol_matcher = KabschMatcher(mol1)
 
-        with pytest.raises(ValueError, match="The order of the species aren't matching! Please try using "):
+        with pytest.raises(
+            ValueError,
+            match="The order of the species aren't matching! Please try using ",
+        ):
             mol_matcher.fit(mol2)
 
     def test_mismatched_atom_order(self):
@@ -336,7 +345,7 @@ class TestKabschMatcher(unittest.TestCase):
         assert rmsd == approx(0, abs=6)
 
 
-class TestHungarianOrderMatcher(unittest.TestCase):
+class TestHungarianOrderMatcher:
     def test_get_rmsd(self):
         mol1 = Molecule.from_file(f"{TEST_DIR}/t3.xyz")
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
@@ -441,7 +450,7 @@ class TestHungarianOrderMatcher(unittest.TestCase):
         assert rmsd == approx(0, abs=6)
 
 
-class TestGeneticOrderMatcher(unittest.TestCase):
+class TestGeneticOrderMatcher:
     def test_get_rmsd(self):
         mol1 = Molecule.from_file(f"{TEST_DIR}/t3.xyz")
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
@@ -546,21 +555,22 @@ class TestGeneticOrderMatcher(unittest.TestCase):
         assert rmsd == approx(0, abs=6)
 
 
-class TestKabschMatcherSi(unittest.TestCase):
+class TestKabschMatcherSi:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si_cluster.xyz")
         cls.mol_matcher = KabschMatcher(cls.mol1)
 
     def test_to_and_from_dict(self):
-        d = self.mol_matcher.as_dict()
-        mol_matcher = KabschMatcher.from_dict(d)
-        assert d == mol_matcher.as_dict()
+        dct = self.mol_matcher.as_dict()
+        mol_matcher = KabschMatcher.from_dict(dct)
+        assert dct == mol_matcher.as_dict()
 
     def test_mismatched_atoms(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
         with pytest.raises(
-            ValueError, match="The order of the species aren't matching! Please try using PermInvMatcher"
+            ValueError,
+            match="The order of the species aren't matching! Please try using BruteForceOrderMatcher",
         ):
             self.mol_matcher.fit(mol2)
 
@@ -582,16 +592,16 @@ class TestKabschMatcherSi(unittest.TestCase):
         assert rmsd == approx(2.7962454578966454, abs=1e-6)
 
 
-class TestBruteForceOrderMatcherSi(unittest.TestCase):
+class TestBruteForceOrderMatcherSi:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si_cluster.xyz")
         cls.mol_matcher = BruteForceOrderMatcher(cls.mol1)
 
     def test_to_and_from_dict(self):
-        d = self.mol_matcher.as_dict()
-        mol_matcher = BruteForceOrderMatcher.from_dict(d)
-        assert d == mol_matcher.as_dict()
+        dct = self.mol_matcher.as_dict()
+        mol_matcher = BruteForceOrderMatcher.from_dict(dct)
+        assert dct == mol_matcher.as_dict()
 
     def test_random_match(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si_cluster_2.xyz")
@@ -603,16 +613,16 @@ class TestBruteForceOrderMatcherSi(unittest.TestCase):
             self.mol_matcher.fit(mol2)
 
 
-class TestHungarianOrderMatcherSi(unittest.TestCase):
+class TestHungarianOrderMatcherSi:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si_cluster.xyz")
         cls.mol_matcher = HungarianOrderMatcher(cls.mol1)
 
     def test_to_and_from_dict(self):
-        d = self.mol_matcher.as_dict()
-        mol_matcher = HungarianOrderMatcher.from_dict(d)
-        assert d == mol_matcher.as_dict()
+        dct = self.mol_matcher.as_dict()
+        mol_matcher = HungarianOrderMatcher.from_dict(dct)
+        assert dct == mol_matcher.as_dict()
 
     def test_mismatched_atoms(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_rotated.xyz")
@@ -642,16 +652,16 @@ class TestHungarianOrderMatcherSi(unittest.TestCase):
         assert rmsd == approx(1.0177241485450828, abs=1e-6)
 
 
-class TestGeneticOrderMatcherSi(unittest.TestCase):
+class TestGeneticOrderMatcherSi:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si_cluster.xyz")
         cls.mol_matcher = GeneticOrderMatcher(cls.mol1, threshold=0.3)
 
     def test_to_and_from_dict(self):
-        d = self.mol_matcher.as_dict()
-        mol_matcher = GeneticOrderMatcher.from_dict(d)
-        assert d == mol_matcher.as_dict()
+        dct = self.mol_matcher.as_dict()
+        mol_matcher = GeneticOrderMatcher.from_dict(dct)
+        assert dct == mol_matcher.as_dict()
 
     def test_mismatched_atoms(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
@@ -679,16 +689,17 @@ class TestGeneticOrderMatcherSi(unittest.TestCase):
         assert res[0][-1] == approx(0.22163169511782, abs=1e-6)
 
 
-class TestKabschMatcherSi2O(unittest.TestCase):
+class TestKabschMatcherSi2O:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
         cls.mol_matcher = KabschMatcher(cls.mol1)
 
     def test_mismatched_atoms(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si_cluster_rotated.xyz")
         with pytest.raises(
-            ValueError, match="The order of the species aren't matching! Please try using PermInvMatcher"
+            ValueError,
+            match="The order of the species aren't matching! Please try using BruteForceOrderMatcher",
         ):
             self.mol_matcher.fit(mol2)
 
@@ -707,14 +718,15 @@ class TestKabschMatcherSi2O(unittest.TestCase):
         # to handle arbitrary atom's order
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_permuted.xyz")
         with pytest.raises(
-            ValueError, match="The order of the species aren't matching! Please try using PermInvMatcher"
+            ValueError,
+            match="The order of the species aren't matching! Please try using BruteForceOrderMatcher",
         ):
             self.mol_matcher.fit(mol2)
 
 
-class TestBruteForceOrderMatcherSi2O(unittest.TestCase):
+class TestBruteForceOrderMatcherSi2O:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
         cls.mol_matcher = BruteForceOrderMatcher(cls.mol1)
 
@@ -743,10 +755,33 @@ class TestBruteForceOrderMatcherSi2O(unittest.TestCase):
         _, rmsd = self.mol_matcher.fit(mol2)
         assert rmsd == approx(0.23051587697194997, abs=1e-6)
 
+    def test_break_on_tol_perturbed_atom_position(self):
+        mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_perturbed.xyz")
+        _, rmsd = self.mol_matcher.fit(mol2, break_on_tol=1e-5)
+        # proceeds as normal and doesn't break early if tol is below possible RMSD
+        assert rmsd == approx(0.2434045087608993, abs=1e-6)
 
-class TestHungarianOrderMatcherSi2O(unittest.TestCase):
+        _, rmsd = self.mol_matcher.fit(mol2, break_on_tol=0.25)
+        # can break early in this case, with tol above possible lowest RMSD
+        assert rmsd == approx(0.2434045087608993, abs=1e-6)
+
+        mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_permuted.xyz")
+        _, rmsd = self.mol_matcher.fit(mol2, break_on_tol=1)
+        # perfect match possible here, breaks once found
+        assert rmsd == approx(0, abs=1e-4)
+
+        mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_2.xyz")
+        _, rmsd = self.mol_matcher.fit(mol2, break_on_tol=2)  # breaks early with higher RMSD, < tol
+        assert rmsd < 2
+
+        mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_2.xyz")
+        _, rmsd = self.mol_matcher.fit(mol2, break_on_tol=0.2)  # doesn't break early, returns orig best RMSD
+        assert rmsd == approx(0.23051587697194997, abs=1e-6)
+
+
+class TestHungarianOrderMatcherSi2O:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
         cls.mol_matcher = HungarianOrderMatcher(cls.mol1)
 
@@ -776,9 +811,9 @@ class TestHungarianOrderMatcherSi2O(unittest.TestCase):
         assert rmsd == approx(0.23231038877573124, abs=1e-6)
 
 
-class TestGeneticOrderMatcherSi2O(unittest.TestCase):
+class TestGeneticOrderMatcherSi2O:
     @classmethod
-    def setUpClass(cls):
+    def setup_class(cls):
         cls.mol1 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
         cls.mol_matcher = GeneticOrderMatcher(cls.mol1, threshold=0.3)
 
