@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-import json
-
+import matplotlib.pyplot as plt
+import orjson
 import pytest
 from numpy.testing import assert_allclose
 from pytest import approx
@@ -9,7 +9,7 @@ from sympy import Number, Symbol
 
 from pymatgen.analysis.surface_analysis import NanoscaleStability, SlabEntry, SurfaceEnergyPlotter, WorkFunctionAnalyzer
 from pymatgen.entries.computed_entries import ComputedStructureEntry
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 __author__ = "Richard Tran"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -22,10 +22,10 @@ __date__ = "Aug 24, 2017"
 TEST_DIR = f"{TEST_FILES_DIR}/surfaces"
 
 
-class TestSlabEntry(PymatgenTest):
-    def setUp(self):
-        with open(f"{TEST_DIR}/ucell_entries.txt") as file:
-            ucell_entries = json.loads(file.read())
+class TestSlabEntry(MatSciTest):
+    def setup_method(self):
+        with open(f"{TEST_DIR}/ucell_entries.txt", encoding="utf-8") as file:
+            ucell_entries = orjson.loads(file.read())
         self.ucell_entries = ucell_entries
 
         # Load objects for O adsorption tests
@@ -58,8 +58,8 @@ class TestSlabEntry(PymatgenTest):
                         assert ads.Nsurfs_ads_in_slab == 1
 
                         # Determine the correct binding energy
-                        with open(f"{TEST_DIR}/isolated_O_entry.txt") as txt_file:
-                            isolated_O_entry = json.loads(txt_file.read())
+                        with open(f"{TEST_DIR}/isolated_O_entry.txt", encoding="utf-8") as txt_file:
+                            isolated_O_entry = orjson.loads(txt_file.read())
                         O_cse = ComputedStructureEntry.from_dict(isolated_O_entry)
                         g_bind = (ads.energy - ml * clean.energy) / Nads - O_cse.energy_per_atom
                         assert g_bind == ads.gibbs_binding_energy()
@@ -118,12 +118,12 @@ class TestSlabEntry(PymatgenTest):
                         assert slab_clean.composition.reduced_composition == clean.composition.reduced_composition
 
 
-class TestSurfaceEnergyPlotter(PymatgenTest):
-    def setUp(self):
+class TestSurfaceEnergyPlotter(MatSciTest):
+    def setup_method(self):
         entry_dict = get_entry_dict(f"{TEST_DIR}/Cu_entries.txt")
         self.Cu_entry_dict = entry_dict
-        with open(f"{TEST_DIR}/ucell_entries.txt") as file:
-            ucell_entries = json.loads(file.read())
+        with open(f"{TEST_DIR}/ucell_entries.txt", encoding="utf-8") as file:
+            ucell_entries = orjson.loads(file.read())
 
         self.Cu_ucell_entry = ComputedStructureEntry.from_dict(ucell_entries["Cu"])
         self.Cu_analyzer = SurfaceEnergyPlotter(entry_dict, self.Cu_ucell_entry)
@@ -253,21 +253,21 @@ class TestSurfaceEnergyPlotter(PymatgenTest):
         surf_ene_plotter = SurfaceEnergyPlotter(all_Pt_slab_entries, self.Pt_analyzer.ucell_entry)
         assert surf_ene_plotter.list_of_chempots == self.Pt_analyzer.list_of_chempots
 
-    @pytest.mark.skip("TODO: need someone to fix this")
+    @pytest.mark.xfail(reason="TODO: need someone to fix this")
     def test_monolayer_vs_BE(self):
         for el in self.Oads_analyzer_dict:
             # Test WulffShape for adsorbed surfaces
             analyzer = self.Oads_analyzer_dict[el]
             analyzer.monolayer_vs_BE()
 
-    @pytest.mark.skip("TODO: need someone to fix this")
+    @pytest.mark.xfail(reason="TODO: need someone to fix this")
     def test_area_frac_vs_chempot_plot(self):
         for el in self.Oads_analyzer_dict:
             # Test WulffShape for adsorbed surfaces
             analyzer = self.Oads_analyzer_dict[el]
             analyzer.area_frac_vs_chempot_plot(x_is_u_ads=True)
 
-    @pytest.mark.skip("TODO: need someone to fix this")
+    @pytest.mark.xfail(reason="TODO: need someone to fix this")
     def test_chempot_vs_gamma_clean(self):
         self.Cu_analyzer.chempot_vs_gamma_clean()
         for el in self.Oads_analyzer_dict:
@@ -275,7 +275,7 @@ class TestSurfaceEnergyPlotter(PymatgenTest):
             analyzer = self.Oads_analyzer_dict[el]
             analyzer.chempot_vs_gamma_clean(x_is_u_ads=True)
 
-    @pytest.mark.skip("TODO: need someone to fix this")
+    @pytest.mark.xfail(reason="TODO: need someone to fix this")
     def test_chempot_vs_gamma_facet(self):
         for el, val in self.metals_O_entry_dict.items():
             for hkl in val:
@@ -283,7 +283,7 @@ class TestSurfaceEnergyPlotter(PymatgenTest):
                 analyzer = self.Oads_analyzer_dict[el]
                 analyzer.chempot_vs_gamma_facet(hkl)
 
-    @pytest.mark.skip("TODO: need someone to fix this")
+    @pytest.mark.xfail(reason="TODO: need someone to fix this")
     def test_surface_chempot_range_map(self):
         for el, val in self.metals_O_entry_dict.items():
             for hkl in val:
@@ -292,8 +292,8 @@ class TestSurfaceEnergyPlotter(PymatgenTest):
                 analyzer.chempot_vs_gamma_facet(hkl)
 
 
-class TestWorkFunctionAnalyzer(PymatgenTest):
-    def setUp(self):
+class TestWorkFunctionAnalyzer(MatSciTest):
+    def setup_method(self):
         self.kwargs = {
             "poscar_filename": f"{TEST_DIR}/CONTCAR.relax1.gz",
             "locpot_filename": f"{TEST_DIR}/LOCPOT.gz",
@@ -309,13 +309,13 @@ class TestWorkFunctionAnalyzer(PymatgenTest):
         assert self.wf_analyzer.is_converged()
 
 
-class TestNanoscaleStability(PymatgenTest):
-    def setUp(self):
+class TestNanoscaleStability(MatSciTest):
+    def setup_method(self):
         # Load all entries
         La_hcp_entry_dict = get_entry_dict(f"{TEST_DIR}/La_hcp_entries.txt")
         La_fcc_entry_dict = get_entry_dict(f"{TEST_DIR}/La_fcc_entries.txt")
-        with open(f"{TEST_DIR}/ucell_entries.txt") as txt_file:
-            ucell_entries = json.loads(txt_file.read())
+        with open(f"{TEST_DIR}/ucell_entries.txt", encoding="utf-8") as txt_file:
+            ucell_entries = orjson.loads(txt_file.read())
         La_hcp_ucell_entry = ComputedStructureEntry.from_dict(ucell_entries["La_hcp"])
         La_fcc_ucell_entry = ComputedStructureEntry.from_dict(ucell_entries["La_fcc"])
 
@@ -358,15 +358,22 @@ class TestNanoscaleStability(PymatgenTest):
         w2 = self.nanoscale_stability.scaled_wulff(fcc_wulff, 10)
         assert w1.effective_radius == approx(w2.effective_radius)
         assert w1.effective_radius == approx(10)
-        assert approx(w2.effective_radius) == 10
+        assert w2.effective_radius == approx(10)
+
+    def test_plot(self):
+        ax = self.nanoscale_stability.plot_all_stability_map(max_r=10.0, labels=["La_hcp", "La_fcc"])
+
+        assert isinstance(ax, plt.Axes)
+        assert "Particle radius" in ax.get_xlabel()
+        assert "$G_{form}$" in ax.get_ylabel()
 
 
 def get_entry_dict(filename):
     # helper to generate an entry_dict
 
     entry_dict = {}
-    with open(filename) as file:
-        entries = json.loads(file.read())
+    with open(filename, encoding="utf-8") as file:
+        entries = orjson.loads(file.read())
     for entry in entries:
         sub_str = entry[25:]
         miller_index = []
@@ -392,8 +399,8 @@ def load_O_adsorption():
     # Loads the dictionary for clean and O adsorbed Rh, Pt, and Ni entries
 
     # Load the adsorbate as an entry
-    with open(f"{TEST_DIR}/isolated_O_entry.txt") as file:
-        isolated_O_entry = json.loads(file.read())
+    with open(f"{TEST_DIR}/isolated_O_entry.txt", encoding="utf-8") as file:
+        isolated_O_entry = orjson.loads(file.read())
     O_entry = ComputedStructureEntry.from_dict(isolated_O_entry)
 
     # entry_dict for the adsorption case, O adsorption on Ni, Rh and Pt
@@ -403,8 +410,8 @@ def load_O_adsorption():
         "Rh": {(1, 0, 0): {}},
     }
 
-    with open(f"{TEST_DIR}/cs_entries_slabs.json") as file:
-        entries = json.loads(file.read())
+    with open(f"{TEST_DIR}/cs_entries_slabs.json", encoding="utf-8") as file:
+        entries = orjson.loads(file.read())
     for key in entries:
         entry = ComputedStructureEntry.from_dict(entries[key])
         for el in metals_O_entry_dict:
@@ -419,8 +426,8 @@ def load_O_adsorption():
                     clean = SlabEntry(entry.structure, entry.energy, (1, 0, 0), label=f"{key}_clean")
                     metals_O_entry_dict[el][1, 0, 0][clean] = []
 
-    with open(f"{TEST_DIR}/cs_entries_o_ads.json") as file:
-        entries = json.loads(file.read())
+    with open(f"{TEST_DIR}/cs_entries_o_ads.json", encoding="utf-8") as file:
+        entries = orjson.loads(file.read())
     for key in entries:
         entry = ComputedStructureEntry.from_dict(entries[key])
         for el, val in metals_O_entry_dict.items():
