@@ -1,44 +1,35 @@
 from __future__ import annotations
 
 import os
-import subprocess
-from typing import TYPE_CHECKING
 
+from pymatgen.cli import pmg
 from pymatgen.util.testing import TEST_FILES_DIR
 
-if TYPE_CHECKING:
-    from pathlib import Path
 
-
-def test_pmg_structure(cd_tmp_path: Path):
-    subprocess.run(
+def test_pmg_structure():
+    pmg.main(
         [
-            "pmg",
             "structure",
             "--convert",
             "--filenames",
             f"{TEST_FILES_DIR}/cif/Li2O.cif",
             "POSCAR_Li2O_test",
         ],
-        check=True,
     )
     assert os.path.isfile("POSCAR_Li2O_test"), "Output file 'POSCAR_Li2O_test' not found"
 
-    subprocess.run(
+    pmg.main(
         [
-            "pmg",
             "structure",
             "--symmetry",
             "0.1",
             "--filenames",
             f"{TEST_FILES_DIR}/cif/Li2O.cif",
         ],
-        check=True,
     )
 
-    subprocess.run(
+    pmg.main(
         [
-            "pmg",
             "structure",
             "--group",
             "element",
@@ -46,17 +37,14 @@ def test_pmg_structure(cd_tmp_path: Path):
             f"{TEST_FILES_DIR}/cif/Li2O.cif",
             f"{TEST_FILES_DIR}/cif/Li.cif",
         ],
-        check=True,
     )
 
-    subprocess.run(
+    pmg.main(
         [
-            "pmg",
             "structure",
             "--localenv",
             "Li-O=3",
             "--filenames",
             f"{TEST_FILES_DIR}/cif/Li2O.cif",
         ],
-        check=True,
     )
