@@ -3,12 +3,12 @@ from __future__ import annotations
 import pytest
 
 from pymatgen.core.molecular_orbitals import MolecularOrbitals
-from pymatgen.util.testing import PymatgenTest
+from pymatgen.util.testing import MatSciTest
 
 test_case = MolecularOrbitals("NaCl")
 
 
-class MolecularOrbitalTestCase(PymatgenTest):
+class TestMolecularOrbital(MatSciTest):
     def test_max_electronegativity(self):
         test_elec_neg = 2.23
         assert test_elec_neg == test_case.max_electronegativity()
