@@ -14,10 +14,10 @@ from pymatgen.core import DummySpecies, Element, Species, get_el_sp
 from pymatgen.core.periodic_table import ElementBase, ElementType
 from pymatgen.core.units import Ha_to_eV
 from pymatgen.io.core import ParseError
-from pymatgen.util.testing import PymatgenTest
+from pymatgen.util.testing import MatSciTest
 
 
-class TestElement(PymatgenTest):
+class TestElement(MatSciTest):
     def test_init(self):
         assert Element("Fe").symbol == "Fe"
 
@@ -29,13 +29,30 @@ class TestElement(PymatgenTest):
 
         assert id(Element("Fe")) == id(Element("Fe"))  # Test caching
 
+    def test_iter(self):
+        # Make sure isotopes don't show during iteration
+        assert [elem.name for elem in Element] == (
+            "H,He,Li,Be,B,C,N,O,F,Ne,Na,Mg,Al,Si,P,S,Cl,Ar,K,Ca,Sc,Ti,V,Cr,"
+            "Mn,Fe,Co,Ni,Cu,Zn,Ga,Ge,As,Se,Br,Kr,Rb,Sr,Y,Zr,Nb,Mo,Tc,Ru,Rh,Pd,"
+            "Ag,Cd,In,Sn,Sb,Te,I,Xe,Cs,Ba,La,Ce,Pr,Nd,Pm,Sm,Eu,Gd,Tb,Dy,Ho,Er,Tm,"
+            "Yb,Lu,Hf,Ta,W,Re,Os,Ir,Pt,Au,Hg,Tl,Pb,Bi,Po,At,Rn,Fr,Ra,Ac,Th,Pa,U,Np,"
+            "Pu,Am,Cm,Bk,Cf,Es,Fm,Md,No,Lr,Rf,Db,Sg,Bh,Hs,Mt,Ds,Rg,Cn,Nh,Fl,Mc,Lv,Ts,Og"
+        ).split(",")
+
+        # Make sure isotopes are still in members
+        assert list(Element.__members__) == (
+            "H,D,T,He,Li,Be,B,C,N,O,F,Ne,Na,Mg,Al,Si,P,S,Cl,Ar,K,Ca,Sc,Ti,V,Cr,"
+            "Mn,Fe,Co,Ni,Cu,Zn,Ga,Ge,As,Se,Br,Kr,Rb,Sr,Y,Zr,Nb,Mo,Tc,Ru,Rh,Pd,"
+            "Ag,Cd,In,Sn,Sb,Te,I,Xe,Cs,Ba,La,Ce,Pr,Nd,Pm,Sm,Eu,Gd,Tb,Dy,Ho,Er,Tm,"
+            "Yb,Lu,Hf,Ta,W,Re,Os,Ir,Pt,Au,Hg,Tl,Pb,Bi,Po,At,Rn,Fr,Ra,Ac,Th,Pa,U,Np,"
+            "Pu,Am,Cm,Bk,Cf,Es,Fm,Md,No,Lr,Rf,Db,Sg,Bh,Hs,Mt,Ds,Rg,Cn,Nh,Fl,Mc,Lv,Ts,Og"
+        ).split(",")
+
     def test_missing_and_confusing_data(self):
         with pytest.warns(UserWarning, match="No data available"):
             _ = Element.H.metallic_radius
         with pytest.warns(UserWarning, match="No data available"):
             _ = Element.Og.ionization_energy
-        with pytest.warns(UserWarning, match="Ambiguous values"):
-            _ = Element.H.refractive_index
 
     def test_is_metal(self):
         for metal in ["Fe", "Eu", "Li", "Ca", "In"]:
@@ -301,7 +318,7 @@ class TestElement(PymatgenTest):
             el = Element.from_Z(idx)
             for elements in keys:
                 key_str = elements.capitalize().replace("_", " ")
-                if key_str in el.data and (not str(el.data[key_str]).startswith("no data")):
+                if key_str in el.data and (el.data[key_str] is not None):
                     assert getattr(el, elements) is not None
                 elif elements == "long_name":
                     assert el.long_name == el.data["Name"]
@@ -316,7 +333,7 @@ class TestElement(PymatgenTest):
             if el.symbol not in {"He", "Ne", "Ar"}:
                 assert el.X > 0, f"No electroneg for {el}"
 
-            # check atomic_orbitals_eV is Ha_to_eV * atomic_orbitals
+        # Check atomic_orbitals_eV is Ha_to_eV * atomic_orbitals
         for el in Element:
             if el.atomic_orbitals is None:
                 continue
@@ -346,18 +363,18 @@ class TestElement(PymatgenTest):
 
     def test_radii(self):
         el = Element.Pd
-        assert el.atomic_radius == 1.40
-        assert el.atomic_radius_calculated == 1.69
-        assert el.van_der_waals_radius == 2.10
+        assert el.atomic_radius == approx(1.40)
+        assert el.atomic_radius_calculated == approx(1.69)
+        assert el.van_der_waals_radius == approx(2.10)
 
     def test_data(self):
-        assert Element.Pd.data["Atomic radius"] == 1.4
+        assert Element.Pd.data["Atomic radius"] == approx(1.4)
         al = Element.Al
         val = al.thermal_conductivity
         assert val == 235
         assert str(val.unit) == "W K^-1 m^-1"
         val = al.electrical_resistivity
-        assert val == 2.7e-08
+        assert val == approx(2.7e-08)
         assert str(val.unit) == "m ohm"
 
     def test_sort(self):
@@ -366,7 +383,7 @@ class TestElement(PymatgenTest):
 
     def test_pickle(self):
         pickled = pickle.dumps(Element.Fe)
-        assert Element.Fe == pickle.loads(pickled)  # noqa: S301
+        assert Element.Fe == pickle.loads(pickled)
 
         # Test 5 random elements
         rng = np.random.default_rng()
@@ -377,7 +394,7 @@ class TestElement(PymatgenTest):
         Element.print_periodic_table()
 
     def test_is(self):
-        assert Element("Bi").is_post_transition_metal, True
+        assert Element("Bi").is_post_transition_metal
 
     def test_isotope(self):
         elems = [Element(el) for el in ("H", "D", "T")]
@@ -391,9 +408,11 @@ class TestElement(PymatgenTest):
             3.0155007134,
         ]
 
+        assert Element.named_isotopes == (Element.D, Element.T)
 
-class TestSpecies(PymatgenTest):
-    def setUp(self):
+
+class TestSpecies(MatSciTest):
+    def setup_method(self):
         self.specie1 = Species.from_str("Fe2+")
         self.specie2 = Species("Fe", 3)
         self.specie3 = Species("Fe", 2)
@@ -406,8 +425,8 @@ class TestSpecies(PymatgenTest):
         assert Species("O0+", spin=2) == Species("O", 0, spin=2)
 
     def test_ionic_radius(self):
-        assert self.specie2.ionic_radius == 78.5 / 100
-        assert self.specie3.ionic_radius == 92 / 100
+        assert self.specie2.ionic_radius == approx(78.5 / 100)
+        assert self.specie3.ionic_radius == approx(92 / 100)
         assert Species("Mn", 4).ionic_radius == approx(0.67)
 
     def test_eq(self):
@@ -433,7 +452,7 @@ class TestSpecies(PymatgenTest):
         assert elem_list == deepcopy(elem_list), "Deepcopy operation doesn't produce exact copy."
 
     def test_pickle(self):
-        assert self.specie1 == pickle.loads(pickle.dumps(self.specie1))  # noqa: S301
+        assert self.specie1 == pickle.loads(pickle.dumps(self.specie1))
         for idx in range(1, 5):
             self.serialize_with_pickle(getattr(self, f"specie{idx}"))
         cs = Species("Cs1+")
@@ -443,7 +462,7 @@ class TestSpecies(PymatgenTest):
             pickle.dump((cs, cl), file)
 
         with open(f"{self.tmp_path}/cscl.pickle", "rb") as file:
-            tup = pickle.load(file)  # noqa: S301
+            tup = pickle.load(file)
             assert tup == (cs, cl)
 
     def test_get_crystal_field_spin(self):
@@ -471,18 +490,18 @@ class TestSpecies(PymatgenTest):
         assert spin == 2
 
     def test_get_nmr_mom(self):
-        assert Species("H").get_nmr_quadrupole_moment() == 2.860
-        assert Species("Li").get_nmr_quadrupole_moment() == -0.808
-        assert Species("Li").get_nmr_quadrupole_moment("Li-7") == -40.1
-        assert Species("Si").get_nmr_quadrupole_moment() == 0.0
+        assert Species("H").get_nmr_quadrupole_moment() == approx(2.860)
+        assert Species("Li").get_nmr_quadrupole_moment() == approx(-0.808)
+        assert Species("Li").get_nmr_quadrupole_moment("Li-7") == approx(-40.1)
+        assert Species("Si").get_nmr_quadrupole_moment() == approx(0)
         with pytest.raises(ValueError, match="No quadrupole moment for isotope='Li-109'"):
             Species("Li").get_nmr_quadrupole_moment("Li-109")
 
     def test_get_shannon_radius(self):
-        assert Species("Li", 1).get_shannon_radius("IV") == 0.59
+        assert Species("Li", 1).get_shannon_radius("IV") == approx(0.59)
         mn2 = Species("Mn", 2)
-        assert mn2.get_shannon_radius("IV", "High Spin") == 0.66
-        assert mn2.get_shannon_radius("V", "High Spin") == 0.75
+        assert mn2.get_shannon_radius("IV", "High Spin") == approx(0.66)
+        assert mn2.get_shannon_radius("V", "High Spin") == approx(0.75)
 
         with pytest.warns(
             UserWarning,
@@ -490,13 +509,13 @@ class TestSpecies(PymatgenTest):
             "spin data available, and that value is returned.",
         ) as warns:
             radius = mn2.get_shannon_radius("V")
-            assert len(warns) == 1
-            assert radius == 0.75
+        assert len(warns) == 1
+        assert radius == approx(0.75)
 
-        assert mn2.get_shannon_radius("VI", "Low Spin") == 0.67
-        assert mn2.get_shannon_radius("VI", "High Spin") == 0.83
-        assert mn2.get_shannon_radius("VII", "High Spin") == 0.9
-        assert mn2.get_shannon_radius("VIII") == 0.96
+        assert mn2.get_shannon_radius("VI", "Low Spin") == approx(0.67)
+        assert mn2.get_shannon_radius("VI", "High Spin") == approx(0.83)
+        assert mn2.get_shannon_radius("VII", "High Spin") == approx(0.9)
+        assert mn2.get_shannon_radius("VIII") == approx(0.96)
 
     def test_sort(self):
         els = map(get_el_sp, ["N3-", "Si4+", "Si3+"])
@@ -548,7 +567,7 @@ class TestSpecies(PymatgenTest):
 def test_symbol_oxi_state_str(symbol_oxi, expected_element, expected_oxi_state):
     species = Species(symbol_oxi)
     assert species._el.symbol == expected_element
-    assert species._oxi_state == pytest.approx(expected_oxi_state, rel=1.0e-6)
+    assert species._oxi_state == approx(expected_oxi_state, rel=1.0e-6)
 
 
 def test_symbol_oxi_state_str_raises():
@@ -594,7 +613,7 @@ class TestDummySpecies:
     def test_pickle(self):
         el1 = DummySpecies("X", 3)
         pickled = pickle.dumps(el1)
-        assert el1 == pickle.loads(pickled)  # noqa: S301
+        assert el1 == pickle.loads(pickled)
 
     def test_sort(self):
         Fe, X = Element.Fe, DummySpecies("X")
@@ -602,13 +621,11 @@ class TestDummySpecies:
         assert DummySpecies("X", 3) < DummySpecies("X", 4)
 
         sp = Species("Fe", 2, spin=5)
-        with pytest.raises(AttributeError) as exc:
+        # This error message is Python version dependent
+        # 3.10: can't set attribute 'spin'
+        # 3.11+: property 'spin' of 'Species' object has no setter
+        with pytest.raises(AttributeError, match=r"(can't set attribute|'Species' object has no setter)"):
             sp.spin = 6
-
-        # for some reason different message on Windows and Mac. on Linux: 'can't set attribute'
-        assert "can't set attribute" in str(exc.value) or "property 'spin' of 'Species' object has no setter" in str(
-            exc.value
-        )
         assert sp.spin == 5
 
     def test_species_electronic_structure(self):
@@ -698,7 +715,7 @@ class TestDummySpecies:
                 if str(el) == "H" and ox == 1:
                     continue
                 n_electron_el = sum(orb[-1] for orb in el.full_electronic_structure)
-                n_electron_sp = sum(orb[-1] for orb in Species(el, ox).full_electronic_structure)
+                n_electron_sp = sum(orb[-1] for orb in Species(el.symbol, ox).full_electronic_structure)
                 assert n_electron_el - n_electron_sp == ox, f"Failure for {el} {ox}"
 
 
