@@ -3,11 +3,11 @@ from __future__ import annotations
 import pytest
 
 from pymatgen.core.xcfunc import XcFunc
-from pymatgen.util.testing import PymatgenTest
+from pymatgen.util.testing import MatSciTest
 
 
-class TestLibxcFunc(PymatgenTest):
-    def setUp(self) -> None:
+class TestLibxcFunc(MatSciTest):
+    def setup_method(self) -> None:
         self.ixc_11 = XcFunc.from_abinit_ixc(11)
 
     def test_aliases(self):
@@ -19,7 +19,7 @@ class TestLibxcFunc(PymatgenTest):
         ixc_1 = XcFunc.from_abinit_ixc(1)
         assert ixc_1.type == "LDA"
         assert ixc_1.name == "LDA_XC_TETER93"
-        assert ixc_1 == ixc_1  # test __eq__
+        assert ixc_1 == ixc_1  # test __eq__  # noqa: PLR0124
         assert ixc_1 == "LDA_XC_TETER93"
         assert ixc_1 != "PBE"
         assert ixc_1.name not in XcFunc.aliases()
@@ -53,7 +53,7 @@ class TestLibxcFunc(PymatgenTest):
         # Test if object can be serialized with Pickle
         self.serialize_with_pickle(self.ixc_11)
 
-    @pytest.mark.skip(reason="TODO:")
+    @pytest.mark.xfail(reason="TODO:")
     def test_msonable(self):
         # Test if object supports MSONable
         self.ixc_11.x.as_dict()
