@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import json
-from unittest import TestCase
 
 from monty.json import MontyDecoder
 from pytest import approx
@@ -10,8 +9,8 @@ from pymatgen.entries.exp_entries import ExpEntry
 from pymatgen.util.testing import TEST_FILES_DIR
 
 
-class TestExpEntry(TestCase):
-    def setUp(self):
+class TestExpEntry:
+    def setup_method(self):
         with open(f"{TEST_FILES_DIR}/entries/Fe2O3_exp.json", encoding="utf-8") as file:
             thermo_data = json.load(file, cls=MontyDecoder)
         self.entry = ExpEntry("Fe2O3", thermo_data)
