@@ -8,7 +8,7 @@ from monty.serialization import loadfn
 from pymatgen.core.structure import Molecule
 from pymatgen.io.qchem.inputs import QCInput
 from pymatgen.io.qchem.sets import OptSet
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 TEST_DIR = f"{TEST_FILES_DIR}/io/qchem"
 
@@ -20,7 +20,7 @@ __email__ = "samblau1@gmail.com"
 __credits__ = "Xiaohui Qu"
 
 
-class TestQCInput(PymatgenTest):
+class TestQCInput(MatSciTest):
     def test_molecule_template(self):
         species = ["C", "O"]
         coords = [
