@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import os
 from pathlib import Path
-from unittest import TestCase
 
 import numpy as np
 import pytest
@@ -27,7 +26,7 @@ from pymatgen.io.phonopy import (
     get_pmg_structure,
     get_thermal_displacement_matrices,
 )
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 try:
     from phonopy import Phonopy
@@ -40,7 +39,7 @@ TEST_DIR = f"{TEST_FILES_DIR}/io/phonopy"
 PHONON_DIR = f"{TEST_FILES_DIR}/phonon"
 
 
-class TestPhonopyParser(PymatgenTest):
+class TestPhonopyParser(MatSciTest):
     def test_get_ph_bs(self):
         ph_bs = get_ph_bs_symm_line(f"{TEST_DIR}/NaCl_band.yaml", has_nac=True)
 
@@ -52,7 +51,7 @@ class TestPhonopyParser(PymatgenTest):
             ph_bs.eigendisplacements[3][50][0],
             [0.0 + 0.0j, 0.14166569 + 0.04098339j, -0.14166569 - 0.04098339j],
         )
-        assert ph_bs.has_eigendisplacements, True
+        assert ph_bs.has_eigendisplacements
         assert_allclose(ph_bs.min_freq()[0].frac_coords, [0, 0, 0])
         assert ph_bs.min_freq()[1] == approx(-0.03700895020)
         assert ph_bs.has_imaginary_freq()
@@ -96,9 +95,9 @@ class TestPhonopyParser(PymatgenTest):
 
 
 @pytest.mark.skipif(Phonopy is None, reason="Phonopy not present")
-class TestStructureConversion(PymatgenTest):
+class TestStructureConversion(MatSciTest):
     def test_structure_conversion(self):
-        struct_pmg = PymatgenTest.get_structure("LiFePO4")
+        struct_pmg = MatSciTest.get_structure("LiFePO4")
         # add magmoms to site_properties
         struct_pmg.add_site_property("magmom", magmoms := [1] * len(struct_pmg))
         struct_ph = get_phonopy_structure(struct_pmg)
@@ -124,7 +123,7 @@ class TestStructureConversion(PymatgenTest):
 
 
 @pytest.mark.skipif(Phonopy is None, reason="Phonopy not present")
-class TestGetDisplacedStructures(PymatgenTest):
+class TestGetDisplacedStructures(MatSciTest):
     def test_get_displaced_structures(self):
         pmg_s = Structure.from_file(f"{TEST_DIR}/POSCAR-unitcell", primitive=False)
         supercell_matrix = np.diag((2, 1, 2))
@@ -156,8 +155,8 @@ class TestGetDisplacedStructures(PymatgenTest):
 
 
 @pytest.mark.skipif(Phonopy is None, reason="Phonopy not present")
-class TestPhonopyFromForceConstants(TestCase):
-    def setUp(self) -> None:
+class TestPhonopyFromForceConstants:
+    def setup_method(self) -> None:
         test_path = Path(TEST_DIR)
         structure_file = test_path / "POSCAR-NaCl"
         fc_file = test_path / "FORCE_CONSTANTS"
@@ -240,7 +239,7 @@ class TestGruneisen:
 
 
 @pytest.mark.skipif(Phonopy is None, reason="Phonopy not present")
-class TestThermalDisplacementMatrices(PymatgenTest):
+class TestThermalDisplacementMatrices(MatSciTest):
     def test_get_thermal_displacement_matrix(self):
         list_matrices = get_thermal_displacement_matrices(
             f"{PHONON_DIR}/thermal_displacement_matrices/thermal_displacement_matrices.yaml",
