@@ -5,12 +5,12 @@ import os
 import pytest
 
 from pymatgen.io.template import TemplateInputGen
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 TEST_DIR = f"{TEST_FILES_DIR}/io"
 
 
-class TestTemplateInputGen(PymatgenTest):
+class TestTemplateInputGen(MatSciTest):
     def test_write_inputs(self):
         input_set = TemplateInputGen().get_input_set(
             template=f"{TEST_DIR}/template_input_file.txt",
@@ -18,7 +18,7 @@ class TestTemplateInputGen(PymatgenTest):
             filename="hello_world.in",
         )
         input_set.write_input(self.tmp_path)
-        with open(f"{self.tmp_path}/hello_world.in") as file:
+        with open(f"{self.tmp_path}/hello_world.in", encoding="utf-8") as file:
             assert "298" in file.read()
 
         with pytest.raises(FileNotFoundError, match="No such file or directory:"):
@@ -42,7 +42,7 @@ class TestTemplateInputGen(PymatgenTest):
 
         input_set.write_input(self.tmp_path, overwrite=True)
 
-        with open(f"{self.tmp_path}/hello_world.in") as file:
+        with open(f"{self.tmp_path}/hello_world.in", encoding="utf-8") as file:
             assert "400" in file.read()
 
         input_set.write_input(self.tmp_path, zip_inputs=True)
