@@ -6,15 +6,15 @@ from pytest import approx
 
 from pymatgen.core.structure import Structure
 from pymatgen.phonon.thermal_displacements import ThermalDisplacementMatrices
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, MatSciTest
 
 TEST_DIR = f"{TEST_FILES_DIR}/phonon/thermal_displacement_matrices"
 
 
-class TestThermalDisplacement(PymatgenTest):
+class TestThermalDisplacement(MatSciTest):
     """Test data from J. George's matlab code https://github.com/JaGeo/MolecularToolbox."""
 
-    def setUp(self) -> None:
+    def setup_method(self) -> None:
         self.thermal = ThermalDisplacementMatrices(
             thermal_displacement_matrix_cart=[
                 [5.16e-03, 6.13e-03, 4.15e-03, -1.10e-04, -1.58e-03, -8.10e-04],
@@ -102,12 +102,20 @@ class TestThermalDisplacement(PymatgenTest):
         # U11, U22, U33, U23, U13, U12
         assert_allclose(
             self.thermal.thermal_displacement_matrix_cart_matrixform[0],
-            [[5.16e-03, -8.10e-04, -1.58e-03], [-8.10e-04, 6.13e-03, -1.10e-04], [-1.58e-03, -1.10e-04, 4.15e-03]],
+            [
+                [5.16e-03, -8.10e-04, -1.58e-03],
+                [-8.10e-04, 6.13e-03, -1.10e-04],
+                [-1.58e-03, -1.10e-04, 4.15e-03],
+            ],
             5,
         )
         assert_allclose(
             self.thermal_with_cif.thermal_displacement_matrix_cart_matrixform[0],
-            [[5.16e-03, -8.10e-04, -1.58e-03], [-8.10e-04, 6.13e-03, -1.10e-04], [-1.58e-03, -1.10e-04, 4.15e-03]],
+            [
+                [5.16e-03, -8.10e-04, -1.58e-03],
+                [-8.10e-04, 6.13e-03, -1.10e-04],
+                [-1.58e-03, -1.10e-04, 4.15e-03],
+            ],
             5,
         )
 
@@ -119,7 +127,16 @@ class TestThermalDisplacement(PymatgenTest):
         assert_allclose(
             Ustar[0],
             ThermalDisplacementMatrices.get_full_matrix(
-                [[1.664527e-04, 2.287923e-04, 1.858146e-05, -1.421950e-06, -1.040138e-05, -3.009800e-05]]
+                [
+                    [
+                        1.664527e-04,
+                        2.287923e-04,
+                        1.858146e-05,
+                        -1.421950e-06,
+                        -1.040138e-05,
+                        -3.009800e-05,
+                    ]
+                ]
             )[0],
             5,
         )
@@ -149,14 +166,32 @@ class TestThermalDisplacement(PymatgenTest):
         assert_allclose(
             beta[0],
             ThermalDisplacementMatrices.get_full_matrix(
-                [[3.285645e-03, 4.516179e-03, 3.667833e-04, -2.806818e-05, -2.053151e-04, -5.941107e-04]]
+                [
+                    [
+                        3.285645e-03,
+                        4.516179e-03,
+                        3.667833e-04,
+                        -2.806818e-05,
+                        -2.053151e-04,
+                        -5.941107e-04,
+                    ]
+                ]
             )[0],
             5,
         )
         assert_allclose(
             beta[-1],
             ThermalDisplacementMatrices.get_full_matrix(
-                [[3.308590e-03, 3.661568e-03, 3.508740e-04, -1.786229e-04, 4.787484e-06, 9.400372e-04]]
+                [
+                    [
+                        3.308590e-03,
+                        3.661568e-03,
+                        3.508740e-04,
+                        -1.786229e-04,
+                        4.787484e-06,
+                        9.400372e-04,
+                    ]
+                ]
             )[0],
             5,
         )
@@ -164,8 +199,7 @@ class TestThermalDisplacement(PymatgenTest):
     def test_write_file(self):
         printed = False
         self.thermal.write_cif(f"{self.tmp_path}/U.cif")
-        with open(f"{self.tmp_path}/U.cif") as file:
-            file.seek(0)  # set position to start of file
+        with open(f"{self.tmp_path}/U.cif", encoding="utf-8") as file:
             lines = file.read().splitlines()  # now we won't have those newlines
             if "_atom_site_aniso_U_12" in lines:
                 printed = True
@@ -300,8 +334,7 @@ class TestThermalDisplacement(PymatgenTest):
         self.thermal.visualize_directionality_quality_criterion(
             filename=f"{self.tmp_path}/U.vesta", other=self.thermal, which_structure=0
         )
-        with open(f"{self.tmp_path}/U.vesta") as file:
-            file.seek(0)  # set position to start of file
+        with open(f"{self.tmp_path}/U.vesta", encoding="utf-8") as file:
             lines = file.read().splitlines()  # now we won't have those newlines
             if "VECTR" in lines:
                 printed = True
@@ -310,6 +343,9 @@ class TestThermalDisplacement(PymatgenTest):
     def test_from_cif_p1(self):
         self.thermal.write_cif(f"{self.tmp_path}/U.cif")
         new_thermals = ThermalDisplacementMatrices.from_cif_P1(f"{self.tmp_path}/U.cif")
-        assert_allclose(new_thermals[0].thermal_displacement_matrix_cif_matrixform, self.thermal.Ucif)
+        assert_allclose(
+            new_thermals[0].thermal_displacement_matrix_cif_matrixform,
+            self.thermal.Ucif,
+        )
         assert_allclose(new_thermals[0].structure.frac_coords, self.thermal.structure.frac_coords)
         assert_allclose(new_thermals[0].structure.volume, self.thermal.structure.volume)
