@@ -6,12 +6,12 @@ from pytest import approx
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.symmetry.kpath import KPathSeek
-from pymatgen.util.testing import PymatgenTest
+from pymatgen.util.testing import MatSciTest
 
 pytest.importorskip("seekpath", reason="seekpath not installed")
 
 
-class TestKPathSeek(PymatgenTest):
+class TestKPathSeek(MatSciTest):
     def test_kpath_generation(self):
         triclinic = [1, 2]
         monoclinic = range(3, 16)
