@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 from datetime import datetime, timedelta, timezone
-from unittest import TestCase
 
 import numpy as np
 import pytest
@@ -20,8 +19,8 @@ __email__ = "ajain@lbl.gov"
 __date__ = "2/14/13"
 
 
-class TestStructureNL(TestCase):
-    def setUp(self):
+class TestStructureNL:
+    def setup_method(self):
         # set up a Structure
         self.struct = Structure(np.eye(3, 3) * 3, ["Fe"], [[0, 0, 0]])
         self.s2 = Structure(np.eye(3, 3) * 3, ["Al"], [[0, 0, 0]])
@@ -46,8 +45,7 @@ class TestStructureNL(TestCase):
             ".com/retrieve/pii/S0927025612006295},\n volume = {68},"
             "\n year = {2013}\n}"
         )
-        repeat = "REPEAT" * 10000
-        self.superlong = f"@misc{{SuperLong,\ntitle = {{{repeat}}}}}"
+        self.superlong = f"@misc{{SuperLong,\ntitle = {{{'REPEAT' * 10000}}}}}"
         self.unicode_title = "@misc{Unicode_Title,\ntitle = {{A \u73ab is a rose}}}"
         self.junk = "This is junk text, not a BibTeX reference"
 
